gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[exchange] 01/02: fix renames in gana


From: gnunet
Subject: [exchange] 01/02: fix renames in gana
Date: Thu, 16 Jan 2025 19:18:19 +0100

This is an automated email from the git hooks/post-receive script.

sebasjm pushed a commit to branch master
in repository exchange.

commit fbe292993f80f178bfc2905f14eb69541571d321
Author: Sebastian <sebasjm@gmail.com>
AuthorDate: Thu Jan 16 15:17:48 2025 -0300

    fix renames in gana
---
 src/exchange/taler-exchange-httpd_age-withdraw_reveal.c | 4 ++--
 src/exchange/taler-exchange-httpd_withdraw.c            | 8 ++++----
 src/util/exchange_signatures.c                          | 8 ++++----
 3 files changed, 10 insertions(+), 10 deletions(-)

diff --git a/src/exchange/taler-exchange-httpd_age-withdraw_reveal.c 
b/src/exchange/taler-exchange-httpd_age-withdraw_reveal.c
index 1bfc86ad2..a02f27bcb 100644
--- a/src/exchange/taler-exchange-httpd_age-withdraw_reveal.c
+++ b/src/exchange/taler-exchange-httpd_age-withdraw_reveal.c
@@ -220,7 +220,7 @@ find_original_commitment (
     case GNUNET_DB_STATUS_SUCCESS_NO_RESULTS:
       *result = TALER_MHD_reply_with_error (connection,
                                             MHD_HTTP_NOT_FOUND,
-                                            
TALER_EC_EXCHANGE_AGE_WITHDRAW_COMMITMENT_UNKNOWN,
+                                            
TALER_EC_EXCHANGE_WITHDRAW_COMMITMENT_UNKNOWN,
                                             NULL);
       return GNUNET_SYSERR;
     case GNUNET_DB_STATUS_HARD_ERROR:
@@ -485,7 +485,7 @@ verify_commitment_and_max_age (
     {
       GNUNET_break_op (0);
       *result = TALER_MHD_reply_with_ec (connection,
-                                         
TALER_EC_EXCHANGE_AGE_WITHDRAW_REVEAL_INVALID_HASH,
+                                         
TALER_EC_EXCHANGE_WITHDRAW_REVEAL_INVALID_HASH,
                                          NULL);
       return GNUNET_SYSERR;
     }
diff --git a/src/exchange/taler-exchange-httpd_withdraw.c 
b/src/exchange/taler-exchange-httpd_withdraw.c
index 3ed555ce0..41da5fc6f 100644
--- a/src/exchange/taler-exchange-httpd_withdraw.c
+++ b/src/exchange/taler-exchange-httpd_withdraw.c
@@ -1888,7 +1888,7 @@ phase_generate_reply_error (
                    wc->rc->connection,
                    MHD_HTTP_CONFLICT,
                    TALER_MHD_PACK_EC (
-                     TALER_EC_EXCHANGE_AGE_WITHDRAW_MAXIMUM_AGE_TOO_LARGE),
+                     TALER_EC_EXCHANGE_WITHDRAW_MAXIMUM_AGE_TOO_LARGE),
                    GNUNET_JSON_pack_uint64 (
                      "allowed_maximum_age",
                      wc->error.details.age.max),
@@ -1908,7 +1908,7 @@ phase_generate_reply_error (
     finish_loop (wc,
                  TEH_RESPONSE_reply_reserve_insufficient_balance (
                    wc->rc->connection,
-                   TALER_EC_EXCHANGE_AGE_WITHDRAW_INSUFFICIENT_FUNDS,
+                   TALER_EC_EXCHANGE_WITHDRAW_INSUFFICIENT_FUNDS,
                    &wc->error.details.reserve_balance,
                    &wc->typ.age.commitment.amount_with_fee,
                    &wc->reserve_pub));
@@ -1919,7 +1919,7 @@ phase_generate_reply_error (
                  TALER_MHD_reply_with_error (
                    wc->rc->connection,
                    MHD_HTTP_BAD_REQUEST,
-                   TALER_EC_EXCHANGE_AGE_WITHDRAW_AMOUNT_OVERFLOW,
+                   TALER_EC_EXCHANGE_WITHDRAW_AMOUNT_OVERFLOW,
                    wc->error.details.which));
     break;
 
@@ -1949,7 +1949,7 @@ phase_generate_reply_error (
                    TALER_MHD_reply_with_error (
                      wc->rc->connection,
                      MHD_HTTP_CONFLICT,
-                     TALER_EC_EXCHANGE_WITHDRAW_BATCH_IDEMPOTENT_PLANCHET,
+                     TALER_EC_EXCHANGE_WITHDRAW_IDEMPOTENT_PLANCHET,
                      NULL));
       break;
     }
diff --git a/src/util/exchange_signatures.c b/src/util/exchange_signatures.c
index a3cdf9dd5..b700b2226 100644
--- a/src/util/exchange_signatures.c
+++ b/src/util/exchange_signatures.c
@@ -388,7 +388,7 @@ GNUNET_NETWORK_STRUCT_BEGIN
 struct TALER_AgeWithdrawConfirmationPS
 {
   /**
    * Purpose is #TALER_SIGNATURE_EXCHANGE_CONFIRM_AGE_WITHDRAW.   Signed by a
    * `struct TALER_ExchangePublicKeyP` using EdDSA.
    */
   struct GNUNET_CRYPTO_EccSignaturePurpose purpose;
@@ -418,7 +418,7 @@ TALER_exchange_online_age_withdraw_confirmation_sign (
 {
 
   struct TALER_AgeWithdrawConfirmationPS confirm = {
-    .purpose.purpose = htonl (TALER_SIGNATURE_EXCHANGE_CONFIRM_AGE_WITHDRAW),
+    .purpose.purpose = htonl (TALER_SIGNATURE_EXCHANGE_CONFIRM_WITHDRAW),
     .purpose.size = htonl (sizeof (confirm)),
     .h_commitment = *h_commitment,
     .noreveal_index = htonl (noreveal_index)
@@ -438,7 +438,7 @@ TALER_exchange_online_age_withdraw_confirmation_verify (
   const struct TALER_ExchangeSignatureP *exchange_sig)
 {
   struct TALER_AgeWithdrawConfirmationPS confirm = {
-    .purpose.purpose = htonl (TALER_SIGNATURE_EXCHANGE_CONFIRM_AGE_WITHDRAW),
+    .purpose.purpose = htonl (TALER_SIGNATURE_EXCHANGE_CONFIRM_WITHDRAW),
     .purpose.size = htonl (sizeof (confirm)),
     .h_commitment = *h_commitment,
     .noreveal_index = htonl (noreveal_index)
@@ -446,7 +446,7 @@ TALER_exchange_online_age_withdraw_confirmation_verify (
 
   if (GNUNET_OK !=
       GNUNET_CRYPTO_eddsa_verify (
-        TALER_SIGNATURE_EXCHANGE_CONFIRM_AGE_WITHDRAW,
+        TALER_SIGNATURE_EXCHANGE_CONFIRM_WITHDRAW,
         &confirm,
         &exchange_sig->eddsa_signature,
         &exchange_pub->eddsa_pub))
@@ -388,7 +388,7 @@ GNUNET_NETWORK_STRUCT_BEGIN
 {
   /**
-   * Purpose is #TALER_SIGNATURE_EXCHANGE_CONFIRM_AGE_WITHDRAW.   Signed by a
+   * Purpose is #TALER_SIGNATURE_EXCHANGE_CONFIRM_WITHDRAW.   Signed by a
    * `struct TALER_ExchangePublicKeyP` using EdDSA.
    */

-- 
To stop receiving notification emails like this one, please contact
gnunet@gnunet.org.



reply via email to

[Prev in Thread] Current Thread [Next in Thread]